@@ -1,4 +1,5 @@
 """A library to supplement Discord.py by adding support for slash commands."""
+from .choices import Choice, Choices
 from .client import CommandClient
 from .commands import SlashCommandInvokeError
 from .options import Channel, Mentionable, option
@@ -11,13 +12,15 @@ from .permissions import (
     guild_permissions,
 )
 
-__version__ = "0.2.0"
+__version__ = "0.3.0"
 __all__ = (
     "__version__",
     "CommandClient",
     "option",
     "Channel",
     "Mentionable",
+    "Choices",
+    "Choice",
     "allow_roles",
     "allow_users",
     "disallow_roles",
